package com.mortals.xhx.module.customer.model;

import java.util.Date;
import java.util.List;
import java.util.ArrayList;

import com.alibaba.fastjson.annotation.JSONField;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.mortals.framework.annotation.Excel;
import com.mortals.framework.model.BaseEntityLong;
import com.mortals.framework.service.IUser;
import com.mortals.framework.util.DataUtil;
import com.mortals.framework.util.DateUtils;
import com.mortals.xhx.common.code.CustomerSatusEnum;
import com.mortals.xhx.common.code.MemberLevelEnum;
import com.mortals.xhx.common.key.Constant;
import com.mortals.xhx.module.customer.model.vo.CustomerVo;
/**
 * 客户管理实体对象
 *
 * @author zxfei
 * @date 2022-07-01
 */

public class CustomerEntity  extends CustomerVo implements IUser {
    private static final long serialVersionUID = 1L;

    /**
     * 用户登录账号
     */
    private String loginName;
    /**
     * 密码
     */
    private String password;
    /**
     * 会员等级，，0：未开启，1：试用客户，2：VIP，3：设计师，默认0
     */
    private Integer memberLevel;
    /**
     * 客户真实名称
     */
    @Excel(name = "真实名称姓名")
    private String custName;
    /**
     * 单位名称
     */
    @Excel(name = "单位名称")
    private String organization;
    /**
     * 联系电话
     */
    @Excel(name = "联系电话")
    private String contactTelphone;
    /**
     * 企业顾问
     */
    private String enterpriseConsultant;
    /**
     * 站点ID
     */
    private Long siteId;
    /**
     * 性别
     */
    private Integer sex;
    /**
     * 邮箱
     */
    private String mailbox;
    /**
     * 职位
     */
    private String job;
    /**
     * 头像图片地址
     */
    private String avatar;
    /**
     * 客户来源
     */
    private Long customerSrc;
    /**
     * 使用状态，1:正常，0:禁用，默认：0
     */
    private Integer status;
    /**
     * 最后一次登录时间
     */
    private Date lastLoginTime;
    /**
     * 最后一次登录地址
     */
    private String lastLoginAddress;

    /**
     * 微信openid
     */
    private String openId;

    /**
     * 密码盐值
     */
    private String saltKey;
    /**
     * 最后一次修改密码时间
     */
    private Date lastUpdatePwdTime;
    /**
     * 当日登录失败数
     */
    private Integer errorCount;
    /**
     * 登录锁定状态0未锁定1已锁定
     */
    private Integer loginLock;
    /**
     * 锁定时间
     */
    private Date lockTime;

    public CustomerEntity(){}
    /**
     * 获取 用户登录账号
     * @return String
     */
    public String getLoginName(){
        return loginName;
    }
    /**
     * 设置 用户登录账号
     * @param loginName
     */
    public void setLoginName(String loginName){
        this.loginName = loginName;
    }
    /**
     * 获取 密码
     * @return String
     */
    public String getPassword(){
        return password;
    }
    /**
     * 设置 密码
     * @param password
     */
    public void setPassword(String password){
        this.password = password;
    }
    /**
     * 获取 会员等级，，0：未开启，1：试用客户，2：VIP，3：设计师，默认0
     * @return Integer
     */
    public Integer getMemberLevel(){
        return memberLevel;
    }
    /**
     * 设置 会员等级，，0：未开启，1：试用客户，2：VIP，3：设计师，默认0
     * @param memberLevel
     */
    public void setMemberLevel(Integer memberLevel){
        this.memberLevel = memberLevel;
        if(memberLevel!=null && MemberLevelEnum.getByValue(memberLevel)!=null) {
            this.setLevelName(MemberLevelEnum.getByValue(memberLevel).getDesc());
        }
    }
    /**
     * 获取 客户真实名称
     * @return String
     */
    public String getCustName(){
        return custName;
    }
    /**
     * 设置 客户真实名称
     * @param custName
     */
    public void setCustName(String custName){
        this.custName = custName;
    }
    /**
     * 获取 单位名称
     * @return String
     */
    public String getOrganization(){
        return organization;
    }
    /**
     * 设置 单位名称
     * @param organization
     */
    public void setOrganization(String organization){
        this.organization = organization;
    }
    /**
     * 获取 联系电话
     * @return String
     */
    public String getContactTelphone(){
        return contactTelphone;
    }
    /**
     * 设置 联系电话
     * @param contactTelphone
     */
    public void setContactTelphone(String contactTelphone){
        this.contactTelphone = contactTelphone;
    }
    /**
     * 获取 企业顾问
     * @return String
     */
    public String getEnterpriseConsultant(){
        return enterpriseConsultant;
    }
    /**
     * 设置 企业顾问
     * @param enterpriseConsultant
     */
    public void setEnterpriseConsultant(String enterpriseConsultant){
        this.enterpriseConsultant = enterpriseConsultant;
    }
    /**
     * 获取 站点ID
     * @return Long
     */
    public Long getSiteId(){
        return siteId;
    }
    /**
     * 设置 站点ID
     * @param siteId
     */
    public void setSiteId(Long siteId){
        this.siteId = siteId;
    }
    /**
     * 获取 性别
     * @return Integer
     */
    public Integer getSex(){
        return sex;
    }
    /**
     * 设置 性别
     * @param sex
     */
    public void setSex(Integer sex){
        this.sex = sex;
    }
    /**
     * 获取 邮箱
     * @return String
     */
    public String getMailbox(){
        return mailbox;
    }
    /**
     * 设置 邮箱
     * @param mailbox
     */
    public void setMailbox(String mailbox){
        this.mailbox = mailbox;
    }
    /**
     * 获取 职位
     * @return String
     */
    public String getJob(){
        return job;
    }
    /**
     * 设置 职位
     * @param job
     */
    public void setJob(String job){
        this.job = job;
    }
    /**
     * 获取 头像图片地址
     * @return String
     */
    public String getAvatar(){
        return avatar;
    }
    /**
     * 设置 头像图片地址
     * @param avatar
     */
    public void setAvatar(String avatar){
        this.avatar = avatar;
    }
    /**
     * 获取 客户来源
     * @return Long
     */
    public Long getCustomerSrc(){
        return customerSrc;
    }
    /**
     * 设置 客户来源
     * @param customerSrc
     */
    public void setCustomerSrc(Long customerSrc){
        this.customerSrc = customerSrc;
    }
    /**
     * 获取 使用状态，1:正常，0:禁用，默认：0
     * @return Integer
     */
    public Integer getStatus(){
        return status;
    }
    /**
     * 设置 使用状态，1:正常，0:禁用，默认：0
     * @param status
     */
    public void setStatus(Integer status){
        this.status = status;
        if(status!=null && CustomerSatusEnum.getByValue(status)!=null) {
            this.setStatusName(CustomerSatusEnum.getByValue(status).getDesc());
        }
    }
    /**
     * 获取 最后一次登录时间
     * @return Date
     */
    public Date getLastLoginTime(){
        return lastLoginTime;
    }
    /**
     * 设置 最后一次登录时间
     * @param lastLoginTime
     */
    public void setLastLoginTime(Date lastLoginTime){
        this.lastLoginTime = lastLoginTime;
        if(lastLoginTime!=null) {
            this.setLastLoginTimeStr(DateUtils.getDateTimeStr(lastLoginTime, "yyyy-MM-dd HH:mm:ss"));
        }
    }
    /**
     * 获取 最后一次登录地址
     * @return String
     */
    public String getLastLoginAddress(){
        return lastLoginAddress;
    }
    /**
     * 设置 最后一次登录地址
     * @param lastLoginAddress
     */
    public void setLastLoginAddress(String lastLoginAddress){
        this.lastLoginAddress = lastLoginAddress;
    }

    public String getOpenId() {
        return openId;
    }

    public void setOpenId(String openId) {
        this.openId = openId;
    }

    public String getSaltKey() {
        return saltKey;
    }

    public void setSaltKey(String saltKey) {
        this.saltKey = saltKey;
    }

    public Date getLastUpdatePwdTime() {
        return lastUpdatePwdTime;
    }

    public void setLastUpdatePwdTime(Date lastUpdatePwdTime) {
        this.lastUpdatePwdTime = lastUpdatePwdTime;
    }

    public Integer getErrorCount() {
        return errorCount;
    }

    public void setErrorCount(Integer errorCount) {
        this.errorCount = errorCount;
    }

    public Integer getLoginLock() {
        return loginLock;
    }

    public void setLoginLock(Integer loginLock) {
        this.loginLock = loginLock;
    }

    public Date getLockTime() {
        return lockTime;
    }

    public void setLockTime(Date lockTime) {
        this.lockTime = lockTime;
    }

    @Override
    public int hashCode() {
        return this.getId().hashCode();
    }
    @Override
    public boolean equals(Object obj) {
        if (obj == null) return false;
        if (obj instanceof CustomerEntity) {
            CustomerEntity tmp = (CustomerEntity) obj;
            if (this.getId() == tmp.getId()) {
                return true;
            }
        }
        return false;
    }

    public String toString(){
        StringBuilder sb = new StringBuilder("");
        sb.append(",loginName:").append(getLoginName());
        sb.append(",password:").append(getPassword());
        sb.append(",memberLevel:").append(getMemberLevel());
        sb.append(",custName:").append(getCustName());
        sb.append(",organization:").append(getOrganization());
        sb.append(",contactTelphone:").append(getContactTelphone());
        sb.append(",enterpriseConsultant:").append(getEnterpriseConsultant());
        sb.append(",siteId:").append(getSiteId());
        sb.append(",sex:").append(getSex());
        sb.append(",mailbox:").append(getMailbox());
        sb.append(",job:").append(getJob());
        sb.append(",avatar:").append(getAvatar());
        sb.append(",customerSrc:").append(getCustomerSrc());
        sb.append(",status:").append(getStatus());
        sb.append(",lastLoginTime:").append(getLastLoginTime());
        sb.append(",lastLoginAddress:").append(getLastLoginAddress());
        return sb.toString();
    }

    public void initAttrValue(){

        this.loginName = "";

        this.password = "";

        this.memberLevel = 0;

        this.custName = "";

        this.organization = "";

        this.contactTelphone = "";

        this.enterpriseConsultant = "";

        this.siteId = null;

        this.sex = null;

        this.mailbox = "";

        this.job = "";

        this.avatar = "";

        this.customerSrc = null;

        this.status = 0;

        this.lastLoginTime = null;

        this.lastLoginAddress = "";
    }

    @Override
    public Long getDeptId() {
        return null;
    }

    @Override
    public String getDeptName() {
        return null;
    }

    @Override
    public Long getCustomerId() {
        return null;
    }


    @Override
    public String getSiteIds() {
        return null;
    }

    @Override
    public String getAreaCodes() {
        return null;
    }

    @Override
    public Long getCustomerJoinId() {
        return null;
    }

    @Override
    public String getCustomerNum() {
        return null;
    }


    @Override
    public String getRealName() {
        return this.custName;
    }

    @Override
    public boolean isAdmin() {
        return false;
    }

    @Override
    public boolean isSystemUser() {
        return false;
    }

    @Override
    public boolean isManager() {
        return false;
    }

    @Override
    public Integer getUserType() {
        return Constant.CUSTOMER_USER;
    }

    @Override
    public String getMenuUrl() {
        return null;
    }
}