package com.mortals.xhx.module.question.service.impl;
import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.Context;
import com.mortals.framework.model.PageInfo;
import com.mortals.xhx.common.code.QuestionRecordType;
import com.mortals.xhx.common.code.QuestionStatusEnum;
import com.mortals.xhx.common.utils.StringUtils;
import com.mortals.xhx.module.question.model.QuestionEntity;
import com.mortals.xhx.module.question.service.QuestionReplyService;
import com.mortals.xhx.module.question.service.QuestionService;
import org.checkerframework.checker.units.qual.A;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.mortals.framework.service.impl.AbstractCRUDServiceImpl;
import com.mortals.xhx.module.question.dao.QuestionRecordDao;
import com.mortals.xhx.module.question.model.QuestionRecordEntity;
import com.mortals.xhx.module.question.service.QuestionRecordService;

import java.util.Date;

/**
* QuestionRecordService
* 问答记录信息 service实现
*
* @author zxfei
* @date 2022-06-28
*/
@Service("questionRecordService")
public class QuestionRecordServiceImpl extends AbstractCRUDServiceImpl<QuestionRecordDao, QuestionRecordEntity, Long> implements QuestionRecordService {

    @Autowired
    private QuestionService questionService;
    @Autowired
    private QuestionReplyService questionReplyService;

    @Override
    protected QuestionRecordEntity findBefore(QuestionRecordEntity params, PageInfo pageInfo, Context context) throws AppException {
        pageInfo.setPrePageResult(-1);
        return super.findBefore(params, pageInfo, context);
    }

    @Override
    public QuestionRecordEntity ask(QuestionRecordEntity entity, Context context) throws AppException {
        entity.setRecordType(QuestionRecordType.QUESTION.getValue());
        entity.setCreateUserName(entity.getCustName());
        entity.setCreateTime(new Date());
        if(entity.getQuestionId()==null){
            QuestionEntity newQuestion = new QuestionEntity();
            newQuestion.initAttrValue();
            newQuestion.setBeginTime(new Date());
            newQuestion.setCustomerId(entity.getCustomerId());
            newQuestion.setCustName(entity.getCustName());
            newQuestion.setContactTelphone(entity.getContactTelphone());
            newQuestion.setOrganization(entity.getOrganization());
            newQuestion.setCreateUserName(entity.getCustName());
            newQuestion.setStatus(QuestionStatusEnum.NOT_FINISHED.getValue());
            newQuestion = questionService.save(newQuestion,context);
            entity.setQuestionId(newQuestion.getId());
            this.dao.insert(entity);

        }else {
            QuestionEntity question = questionService.get(entity.getQuestionId());
            if(question==null){
                throw new AppException("问答不存在,请从新发起咨询");
            }
            this.dao.insert(entity);
        }
        String replyContent = questionReplyService.autoReplyQuestion(entity.getContent());
        if(StringUtils.isNotEmpty(replyContent)){
            QuestionRecordEntity recordEntity = new QuestionRecordEntity();
            recordEntity.setQuestionId(entity.getQuestionId());
            recordEntity.setContent(replyContent);
            recordEntity.setRecordType(QuestionRecordType.ANSWER.getValue());
            recordEntity.setCreateUserName("系统回复");
            recordEntity.setCreateTime(new Date());
            this.dao.insert(recordEntity);
        }
        return entity;
    }

    @Override
    public QuestionRecordEntity answer(QuestionRecordEntity entity, Context context) throws AppException {
        QuestionEntity question = questionService.get(entity.getQuestionId());
        if(question==null){
            throw new AppException("问答不存在,请从新选择问题");
        }
        entity.setRecordType(QuestionRecordType.ANSWER.getValue());
        entity.setCreateUserName(entity.getCustName());
        entity.setCreateTime(new Date());
        this.dao.insert(entity);
        return entity;
    }
}