package com.mortals.xhx.module.thirdlog.sms;

import cn.hutool.core.util.IdUtil;
import com.alibaba.fastjson.JSONObject;
import com.mortals.framework.annotation.UnAuth;
import com.mortals.framework.common.Rest;
import com.mortals.framework.model.Context;
import com.mortals.framework.service.IAuthTokenService;
import com.mortals.framework.service.ICacheService;
import com.mortals.framework.util.DateUtils;
import com.mortals.framework.util.StringUtils;
import com.mortals.framework.web.BaseJsonBodyController;
import com.mortals.xhx.base.login.web.LoginForm;
import com.mortals.xhx.module.customer.model.CustomerEntity;
import com.mortals.xhx.module.customer.service.CustomerService;
import com.mortals.xhx.module.thirdlog.sms.pdu.SMSLoginPdu;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

@RestController
@RequestMapping("sms")
public class SMSLoginController extends BaseJsonBodyController {

    @Autowired
    private CustomerService customerService;
    @Autowired
    private IAuthTokenService authTokenService;

    @PostMapping({"send"})
    @UnAuth
    public Rest<Object> sendSmsVerifyCode(@RequestBody SMSLoginPdu smsLoginPdu){
        Rest<Object> ret = new Rest();
        Map<String, Object> model = new HashMap();
        Context context = this.getContext();
        String busiDesc = "发送手机验证码";

        int code=1;
        try {
            customerService.sendSmsVerifyCode(smsLoginPdu.getMobileNumber());
            model.put("message_info", busiDesc + "成功");
            this.recordSysLog(this.request, busiDesc + " 【成功】");
        } catch (Exception var9) {
            code = -1;
            this.doException(this.request, busiDesc, model, var9);
        }

        ret.setCode(code);
        ret.setData(model);
        ret.setDict(model.get("dict"));
        ret.setMsg(model.get("message_info") == null ? "" : model.remove("message_info").toString());
        return ret;
    }

    @PostMapping("login")
    @UnAuth
    public String login(@RequestBody SMSLoginPdu smsLoginPdu) throws Exception {
        JSONObject ret = new JSONObject();
        Map<String, Object> data = new HashMap<>();
        String ip = super.getRequestIP(request);
        CustomerEntity customerEntity = null;
        try {
            customerEntity = customerService.doSmsLogin(smsLoginPdu.getMobileNumber(), smsLoginPdu.getVerifyCode(), ip);
            customerEntity.setLastLoginAddress(ip);
            customerEntity.setLoginTime(System.currentTimeMillis());
            customerEntity.setToken(IdUtil.fastSimpleUUID());
            customerEntity.setExpireTime(DateUtils.addCurrDate(7).getTime());
            String token = authTokenService.createToken(customerEntity);
            data.put("token", token);
            data.put("customer", customerEntity);
            recordSysLog(request, customerEntity, "客户登录系统成功!");
            ret.put(KEY_RESULT_DATA, data);
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_SUCCESS);
            ret.put(KEY_RESULT_MSG, "用户登录系统成功!");
            return ret.toJSONString();
        } catch (Exception e) {
            log.error("login error ", e);
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }
}
